.. _doc-manage:

############################
 Managing a Camelot project
############################

:Release: |version|
:Date: |today|

Once a project has been created and set up as described in the tutorial
:ref:`tutorial-videostore`, it needs to be maintained and managed over time.

.. seealso:: :ref:`doc-schemas`

Two tools exist to assist in the management of Camelot projects:
:program:`camelot_admin.py` and :program:`camelot_manage.py`.

.. _camelot_admin:

camelot_admin.py
================

.. automodule:: camelot.bin.camelot_admin

camelot_manage.py
=================

.. automodule:: camelot.bin.camelot_manage

